@@ -1,19 +1,20 @@
 metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                      data=NULL, subset=NULL,
-                     sm="MD",
-                     level=0.95, level.comb=level,
-                     comb.fixed=TRUE, comb.random=TRUE,
-                     hakn=FALSE,
-                     method.tau="DL", tau.preset=NULL, TE.tau=NULL,
-                     tau.common=FALSE,
-                     prediction=FALSE, level.predict=level,
-                     method.bias="linreg",
-                     title="", complab="", outclab="",
-                     label.e="Experimental", label.c="Control",
-                     label.left="", label.right="",
-                     byvar, bylab, print.byvar=TRUE,
-                     keepdata=TRUE,
-                     warn=TRUE
+                     sm=.settings$smcont,
+                     level=.settings$level, level.comb=.settings$level.comb,
+                     comb.fixed=.settings$comb.fixed, comb.random=.settings$comb.random,
+                     hakn=.settings$hakn,
+                     method.tau=.settings$method.tau, tau.preset=NULL, TE.tau=NULL,
+                     tau.common=.settings$tau.common,
+                     prediction=.settings$prediction, level.predict=.settings$level.predict,
+                     method.bias=.settings$method.bias,
+                     ##
+                     title=.settings$title, complab=.settings$complab, outclab="",
+                     label.e=.settings$label.e, label.c=.settings$label.c,
+                     label.left=.settings$label.left, label.right=.settings$label.right,
+                     byvar, bylab, print.byvar=.settings$print.byvar,
+                     keepdata=.settings$keepdata,
+                     warn=.settings$warn
                      ){
   
   
@@ -204,6 +205,7 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                     mean.e - mean.c)
     seTE <- ifelse(npn, NA,
                    sqrt(sd.e^2/n.e + sd.c^2/n.c))
+    seTE[is.na(TE)] <- NA
   }
   else if (sm == "SMD"){
     N <- n.e+n.c
@@ -212,8 +214,9 @@ metacont <- function(n.e, mean.e, sd.e, n.c, mean.c, sd.c, studlab,
                     sqrt(((n.e-1)*sd.e^2 + (n.c-1)*sd.c^2)/(N-2)))
     seTE <- ifelse(npn, NA,
                    sqrt(N / (n.e*n.c) + TE^2/(2*(N-3.94))))
+    seTE[is.na(TE)] <- NA
   }
-  ##  
+  ##
   ## Studies with zero variance get zero weight in meta-analysis
   ## (added by sc, 3.6.2008):
   ##
